emacs-elpa-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[elpa] externals/compat 501acae2b9: Fix buffer-match-p


From: ELPA Syncer
Subject: [elpa] externals/compat 501acae2b9: Fix buffer-match-p
Date: Thu, 5 Jan 2023 06:57:27 -0500 (EST)

branch: externals/compat
commit 501acae2b924f483f261d24e46506a88091c96ea
Author: Daniel Mendler <mail@daniel-mendler.de>
Commit: Daniel Mendler <mail@daniel-mendler.de>

    Fix buffer-match-p
---
 compat-29.el | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/compat-29.el b/compat-29.el
index e8fc511aa9..2280d5e5a2 100644
--- a/compat-29.el
+++ b/compat-29.el
@@ -273,7 +273,7 @@ CONDITION is either:
   * `major-mode': the buffer matches if the buffer's major mode
     is eq to the cons-cell's cdr.  Prefer using `derived-mode'
     instead when both can work.
   * `not': the cdr is interpreted as a negation of a condition.
   * `and': the cdr is a list of recursive conditions, that all have
     to be met.
   * `or': the cdr is a list of recursive condition, of which at
@@ -302,7 +302,7 @@ CONDITION is either:
                        (buffer-local-value 'major-mode buffer)
                        (cdr condition)))
                      ((eq (car-safe condition) 'not)
-                      (not (funcall match (cdr condition))))
+                      (not (funcall match (cadr condition))))
                      ((eq (car-safe condition) 'or)
                       (funcall match (cdr condition)))
                      ((eq (car-safe condition) 'and)
@@ -273,7 +273,7 @@ CONDITION is either:
     is eq to the cons-cell's cdr.  Prefer using `derived-mode'
     instead when both can work.
-  * `not': the cdr is interpreted as a negation of a condition.
+  * `not': the cadr is interpreted as a negation of a condition.
   * `and': the cdr is a list of recursive conditions, that all have
     to be met.



reply via email to

[Prev in Thread] Current Thread [Next in Thread]